(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     65223,       2207]*)
(*NotebookOutlinePosition[     65857,       2230]*)
(*  CellTagsIndexPosition[     65813,       2226]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(path = "\</auto/procsv23/mnt1/lothar/BARRIER/NewMath/\>"; \n
    Get[path<>"\<15_Picture2BarCompareToYamamotoResonancePeaks.txt\>"]\)], 
  "Input"],

Cell["\<\
<</auto/procsv23/mnt1/lothar/BARRIER/NewMath/00_definitions.common
setYamamotoFunctions
<</auto/procsv23/mnt1/lothar/BARRIER/NewMath/03_definitions.transferMatrix
<</auto/procsv23/mnt1/lothar/BARRIER/NewMath/04_definitions.\
singleBarrierMatrix
<</auto/procsv23/mnt1/lothar/BARRIER/NewMath/05_definitions.sigma1_e_gt_V1
<</auto/procsv23/mnt1/lothar/BARRIER/NewMath/06_definitions.sigma1_e_le_V1
<</auto/procsv23/mnt1/lothar/BARRIER/NewMath/08_definitions.\
doubleBarrierMatrix
<</auto/procsv23/mnt1/lothar/BARRIER/NewMath/09_definitions.\
doubleBarrierTransmissionCoefficient
<</auto/procsv23/mnt1/lothar/BARRIER/NewMath/15_definitions.\
ComputationResonancePeaks
<</auto/procsv23/mnt1/lothar/BARRIER/NewMath/15_\
Picture2BarCompareToYamamotoResonancePeaks.txt
setPlotFunctions\
\>", "Print"]
}, Open  ]],

Cell["(* Determine the value of the resonance energy *)", "Input"],

Cell["(* (I) Upper Peak: LMS paper *)", "Input"],

Cell[CellGroupData[{

Cell["\<\
N[
tau2[ b1
     ,I beta1[m1,e,V1]
     ,m1
     ,w
     ,k[m,e]
     ,m
     ,b2
     ,I beta1[m2,e,V2]
     ,m2
    ]//.{e->.2543858electronVolt}
 ,10]\
\>", "Input"],

Cell[OutputFormData["\<\
0.9999999999856834\
\>", "\<\
1.\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
eBase=.2543858;
Plot[  tau2[  b1
             ,I beta1[m1,e electronVolt,V1]
             ,m1
             ,w
             ,k[m,e electronVolt]
             ,m
             ,b2
             ,I beta1[m2,e electronVolt,V2]
             ,m2
           ]
      , {e,.99999eBase,1.00001eBase}];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-47618.6 187192 -916173 916174 [
[.35025 .22435 -24 -9 ]
[.35025 .22435 24 0 ]
[.53744 .22435 -24 -9 ]
[.53744 .22435 24 0 ]
[.72463 .22435 -24 -9 ]
[.72463 .22435 24 0 ]
[.91182 .22435 -24 -9 ]
[.91182 .22435 24 0 ]
[.15055 .05362 -48 -4.5 ]
[.15055 .05362 0 4.5 ]
[.15055 .14523 -48 -4.5 ]
[.15055 .14523 0 4.5 ]
[.15055 .32847 -6 -4.5 ]
[.15055 .32847 0 4.5 ]
[.15055 .42009 -6 -4.5 ]
[.15055 .42009 0 4.5 ]
[.15055 .5117 -6 -4.5 ]
[.15055 .5117 0 4.5 ]
[.15055 .60332 -6 -4.5 ]
[.15055 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.35025 .23685 m
.35025 .2431 L
s
[(0.254385)] .35025 .22435 0 1 Mshowa
.53744 .23685 m
.53744 .2431 L
s
[(0.254386)] .53744 .22435 0 1 Mshowa
.72463 .23685 m
.72463 .2431 L
s
[(0.254387)] .72463 .22435 0 1 Mshowa
.91182 .23685 m
.91182 .2431 L
s
[(0.254388)] .91182 .22435 0 1 Mshowa
.125 Mabswid
.20049 .23685 m
.20049 .2406 L
s
.23793 .23685 m
.23793 .2406 L
s
.27537 .23685 m
.27537 .2406 L
s
.31281 .23685 m
.31281 .2406 L
s
.38768 .23685 m
.38768 .2406 L
s
.42512 .23685 m
.42512 .2406 L
s
.46256 .23685 m
.46256 .2406 L
s
.5 .23685 m
.5 .2406 L
s
.57488 .23685 m
.57488 .2406 L
s
.61232 .23685 m
.61232 .2406 L
s
.64975 .23685 m
.64975 .2406 L
s
.68719 .23685 m
.68719 .2406 L
s
.76207 .23685 m
.76207 .2406 L
s
.79951 .23685 m
.79951 .2406 L
s
.83695 .23685 m
.83695 .2406 L
s
.87438 .23685 m
.87438 .2406 L
s
.12562 .23685 m
.12562 .2406 L
s
.08818 .23685 m
.08818 .2406 L
s
.05074 .23685 m
.05074 .2406 L
s
.0133 .23685 m
.0133 .2406 L
s
.94926 .23685 m
.94926 .2406 L
s
.9867 .23685 m
.9867 .2406 L
s
.25 Mabswid
0 .23685 m
1 .23685 L
s
.16305 .05362 m
.1693 .05362 L
s
[(0.999999)] .15055 .05362 1 0 Mshowa
.16305 .14523 m
.1693 .14523 L
s
[(0.999999)] .15055 .14523 1 0 Mshowa
.16305 .32847 m
.1693 .32847 L
s
[(1)] .15055 .32847 1 0 Mshowa
.16305 .42009 m
.1693 .42009 L
s
[(1)] .15055 .42009 1 0 Mshowa
.16305 .5117 m
.1693 .5117 L
s
[(1)] .15055 .5117 1 0 Mshowa
.16305 .60332 m
.1693 .60332 L
s
[(1)] .15055 .60332 1 0 Mshowa
.125 Mabswid
.16305 .07194 m
.1668 .07194 L
s
.16305 .09026 m
.1668 .09026 L
s
.16305 .10859 m
.1668 .10859 L
s
.16305 .12691 m
.1668 .12691 L
s
.16305 .16356 m
.1668 .16356 L
s
.16305 .18188 m
.1668 .18188 L
s
.16305 .2002 m
.1668 .2002 L
s
.16305 .21853 m
.1668 .21853 L
s
.16305 .25517 m
.1668 .25517 L
s
.16305 .2735 m
.1668 .2735 L
s
.16305 .29182 m
.1668 .29182 L
s
.16305 .31014 m
.1668 .31014 L
s
.16305 .34679 m
.1668 .34679 L
s
.16305 .36511 m
.1668 .36511 L
s
.16305 .38344 m
.1668 .38344 L
s
.16305 .40176 m
.1668 .40176 L
s
.16305 .43841 m
.1668 .43841 L
s
.16305 .45673 m
.1668 .45673 L
s
.16305 .47506 m
.1668 .47506 L
s
.16305 .49338 m
.1668 .49338 L
s
.16305 .53003 m
.1668 .53003 L
s
.16305 .54835 m
.1668 .54835 L
s
.16305 .56667 m
.1668 .56667 L
s
.16305 .585 m
.1668 .585 L
s
.16305 .03529 m
.1668 .03529 L
s
.16305 .01697 m
.1668 .01697 L
s
.25 Mabswid
.16305 0 m
.16305 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .0257 m
.06244 .11604 L
.10458 .20581 L
.14415 .2818 L
.18221 .34729 L
.22272 .40881 L
.26171 .46006 L
.30316 .50595 L
.34309 .54181 L
.3815 .56857 L
.40095 .57923 L
.42237 .58871 L
.43215 .59226 L
.44268 .59552 L
.45255 .59807 L
.46172 .59998 L
.47182 .60159 L
.47716 .60223 L
.47989 .6025 L
.48285 .60275 L
.48568 .60295 L
.48828 .60309 L
.49076 .60319 L
.49201 .60324 L
.49339 .60327 L
.49463 .60329 L
.49577 .60331 L
.49708 .60332 L
.49833 .60332 L
.49948 .60331 L
.50054 .6033 L
.5017 .60328 L
.50294 .60325 L
.50532 .60317 L
.50783 .60306 L
.51231 .60277 L
.51713 .60235 L
.52241 .60175 L
.53188 .60032 L
.54069 .59858 L
.56115 .59298 L
.57974 .58603 L
.61972 .56506 L
.65818 .53713 L
.6991 .49906 L
.73851 .45426 L
.77639 .40366 L
.81673 .34167 L
.85556 .2741 L
.89683 .19377 L
Mistroke
.9366 .1081 L
.97484 .01803 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`0006BEkOl0003o
0?oo0000ool0o`3ooonUChj>S_oTa?GemOoN[M?CdmWIfGAdM:VYZEnNX39DEKWEeW:OolCGociGS<d0
0;no_de=CF67fNKViW=cLjo^k[jn_ZG0`JVmj?l0VJRmj:Nlj:JljJ>kjYZhk7n[l011`_JPCObfHog5
HOOILNkXa]3HgkC^]000?`00Onc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a/JRXZ:2PX=Ro
f000_`0o000o?h:2PWmoO`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3o
O`3o_cl003l0?cl0Ocl0_cl0oclo07EeMGalO3lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo?kooOkoo_kooool0?ol0Ool0_olo
0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOooo_h9cPYVIVN[Z
jZNWYjj^[WMgMko>i[K8j;75j:o3jOooonk^k]gMgLc<c;^k^jZZZYVIVHR8R7MgMfIVIUEEEDA4A3<c
<b8R8Q4A4@000:g1jJc0jJ^ojJZojJVojJVnjJRnjJNmjJJmjJFljJBkjJBjjJ>jjJ6ijJ2gjIjfjIbd
jIVaj9J^j9:[ihfUiHJOhgjGh7F<g6UoeUeacU1PaD=@^SQ1[c4eYRd^Wbh[Vc<]VShfWeA?[j>lj`00
@PP0C`d0D0`0B`P0@P40=0008@001jNmj9bhk8N_kaU^gol08@0003<000<10000jP0003<000<10000
jP0003<000<10000jP0003<000<10000jP0003<000<10000hP000`4000050000<`020N8000<10000
1P0003<000<10000h@000`400006000030000`40000T00030@000>0000<100001`0000`000<10000
90000`40003P00030@0000L0000=00030@0002<000<10000g`000`40000800003@000`40000S0081
h0000`40000800003P000`40000R00030@000=l000<10000200000h000<100008P000`40003N0003
0@0000T0000?00030@00024000<10000gP000`40000900000P020@@000<100000P030@<00`4300<1
0`030@<00`4300<11@000`40003M00030@0000X000001@01000100X00P4500030@0000<000<10000
0`000`40000300030@0000<000<100000P030Md000<100002P000005004000402`000`4000030003
0@0000<000<100000`000`40000300030@0000<000<100000P000`40003M00030@0000X000001@01
000100T00`4300<10`030@<00`4300<10`030@@000<10000g0000`40000;000000D00@000@080003
0@00008100D00@000@0200040@000@8000@100010P001040004200040@000@@000<10000g0000`40
000;000000D00@000@0800030@00008100D00@000@0200040@000@8000@100010P00104000420004
0@000@@000<10000f`000`40000<00000P020@X00P4200040@010@@00P44008110020@@00P450081
g0000`40000<00004P000`40000N00030@000=/000<100003000018000<100007P000`40003J0003
0@0000d0000C00030@0001d000<10000fP000`40000=00004`000`40000M00030@000=T000<10000
3P0001@000<1000070020MX000<100003P0001@000<1000070000`40003I00030@0000h0000D0003
0@0001`000<10000f0000`40000?00005@000`40000K00030@000=P000<100003`0001D000<10000
6`000`40003G00030@000100000F00030@0001X00P7H00030@000100000F00030@0001X000<10000
e`000`40000@00005`000`40000I00030@000=H000<100004@0001L000<100006@000`40003F0003
0@000140000G00030@0001T000<10000e@000`40000B000060000`40000H00030@000=D000<10000
4P0001P000<1000060020MD000<100004`0001T000<100005`000`40003D00030@0001<0000I0003
0@0001L000<10000d`000`40000D00000P020@@000<100000P030@<00`4300<10`030@<00`4300<1
1@000`40003C00030@0001@000001@01000100/000<100000`001`40000100401@000`4000030003
0@0000<000<100000P000`40003B00030@0001D000001@01000100/000<100000`000`4000020081
1@000`40000300030@0000<000<100000P030M8000<100005@000005004000402@030@<00`4300<1
0`030@<00`4300<110000`40003A00030@0001H000001@01000100P000@100010P00104000420004
0@000@8000@100010P001040004200040@000@@000<10000d@000`40000F000000D00@000@080004
0@000@8000@100010P001040004200040@000@8000@100010P001040004400030@000=0000<10000
5`0000800P4:008110020@@00P40100100020@@00P4400811@000`40003@00030@0001L0000M0003
0@0001<00P7@00030@0001P0000N00030@00018000<10000c`000`40000H00007P000`40000B0003
0@000<h000<100006@0001l000<100004@000`40003>00030@0001T0000O00030@00014000<10000
c@000`40000J000080000`40000@0081cP000`40000J000080000`40000@00030@000<`000<10000
6`00024000<100003`000`40003<00030@0001/0000Q00030@0000l000<10000b`000`40000L0000
8P000`40000>00030@000</000<100007000028000<100003P020L/000<100007@0002<000<10000
3@000`40003:00030@0001d0000S00030@0000d000<1000070020@@000<100000P040@800`450003
0@0000800P4400810`030@P00P4400030@000080104200<11@000`400002008110020@@00P490081
10000`40000200@10P030@D000<100000P020@@00P4400030@0000P00P4400030@0000801@401001
0@4500030@0000800P44008110020@@0000T00030@0000`000<100006`001040004800030@0000H0
00<100000P001@400001008000@100010P000`40000300030@0000@000@1000120000`4000060003
0@00008000D100000@0200040@000@8000@100010P000`40000500040@000@P000<100001P000`40
000200050@0000400P001040004200050@0000402@001040004800050@00004010000`4000020005
0@0000400P001040004200040@000@8000<100000@0002@000<1000030000`40000K00040@000@T0
00<100001@000`400@040@D000@100010P000`40000300030@0000@000@100012@000`4000050003
0@0100@11@001040004200040@000@8000<100001@001040004900030@0000D000<1004010450004
0@000@8000<100000P000`40000600040@000@T000<100401@000`400@040@D000@100010P001040
004200030@000040000U00030@0000/00P4L00040@000@X000@100000`4200040@000@@00P440081
0`030@L000@100012P00104000030@8000@1000110020@@00P4300<120001040004:00040@0000<1
0P0010400044008110020@D000<100001P001040004:00810P030@8000@1000110020@@00P440081
100002D000<100002`000`40000K00040@000@/000@100011@000`400@0600040@000@8000@10001
2@001040004;00040@000@D000<100401P001040004200040@000@X000@100012`00104000450003
0@0100H000@100010P000`40000300030@0000D000@100012P020@8000<100000`000`400@060004
0@000@8000@100010P000`40000100009P000`40000:00030@0001/000@100012000104000420003
0@0000@00P4300040@000@8000@100010P000`40000700040@000@P000@100010P000`4000040081
0`001040004200040@000@8000<1000020001040004800040@000@8000<1000010020@<000@10001
0P001040004200040@000@L000@10001200010400@4200030@0000@00P4300040@000@8000@10001
0P001040004300009P000`40000:00030@0001`00P4:00810`040@@000<100000P020@@00P4300@1
1`020@X00P4300@110000`400002008110020@@00`4800812P020@<0104400030@0000800P440081
0`040@P00P4:00810`040@@000<100000P020@@00P440081100002L000<100002@000`4000360003
0@000240000W00030@0000T000<10000a@000`40000R00001@3o0A`1000900030@0000L000<10000
20000`40000700030@0000P000<1000020000`40000700030@0000P000<100001`000`4000080003
0@0000L000<1000020000`40000700030@0000P000<100001`000`40000800030@0000L000<10000
20000`40000700030@0000P000<1000020000`40000700030@0000P000<100001P020@X000<10000
1`000`40000800030@000080000Y00030@0000L000<10000a0000`40000S0000:@000`4000070003
0@000<<000<10000900002X000<100001P000`40003300030@0002@0000Z00030@0000H00P730003
0@0002D0000[00030@0000D000<10000`P000`40000U0000:`000`40000500030@000<4000<10000
9P0002`000<1000010000`40003100030@0002H0000/00030@0000@000<10000`0000`40000W0000
;@000`4000030081`@000`40000W0000;@000`40000300030@000;l000<10000:00002h000<10000
0P000`40002o00030@0002P0000_00050@000040`0000`40000Y0000;`001@4000010<0000<10000
:@00030000<100000P6n00030@0002X0000`00040@000Kl000<10000:P00034000<10040_P000`40
000[0000<@000`400@2m00030@0002`0000b0081_@000`40000/0000<P030K/000<10000;@0003<0
00<10000^P000`40000]0000<`000`40002i00030@0002h0000c0081^@000`40000_0000:`040@@0
0P6i00030@0002l0000]00030@0000<00`6g00030@000300000]00030@0000<000<10040]`000`40
000`0000;@000`40000300040@000KD000<10000<@0002d000<100000`001040006e00030@000340
000[00<11@001@4000010;<000<10000<P0002d000<100000`020@8000<10000/0000`40000c0000
<`000`40000200030@000:l000<10000<`0003<000<100000`000`40002]00030@0003@0000c0003
0@0000<000<10000[0000`40000e0000<`000`40000400030@000:/000<10000=@0003<000<10000
1@000`40002Y00030@0003H0000c00811`000`40002W00030@0003L0000c00030@0000H000<10000
Y`000`40000g0000<`000`40000700030@000:D000<10000>00003<000<1000020000`40002T0003
0@0003P0000c00030@0000P000<10000X`000`40000i0000<`020@X000<10000X@000`40000j0000
<`000`40000:00030@000:0000<10000>P0003<000<100002P000`40002O00030@0003/0000c0003
0@0000/000<10000W@000`40000l0000<`000`40000<00030@0009`000<10000?00003<00P4>0003
0@0009X000<10000?@0003<000<100003@000`40002I00030@0003h0000c00030@0000h000<10000
V0000`40000n0000<`000`40000?00030@0009H000<10000?`0002/0104400030@00010000<10000
U0000`4000100000;@000`40000300<140000`40002C00030@000440000]00030@0000<000<10000
4@000`40002B00030@000440000]00030@0000<000<100004P000`40002@00030@000480000]0003
0@0000<000<100004`000`40002>00030@0004<0000[00<11@000`40000D00030@0008`000<10000
A00002d000<100000`020AD000<10000S0000`4000140000<`000`40000E00030@0008X000<10000
A@0003<000<100005P000`40002800030@0004H0000c00030@0001L000<10000QP000`4000170000
<`000`40000G00030@0008H000<10000A`0003<00P4I00030@0008@000<10000B00003<000<10000
6@000`40002200030@0004T0000c00030@0001X000<10000P0000`40001:0000<`000`40000K0003
0@0007h000<10000B`0003<000<1000070000`40001l00030@0004`0000c00030@0001`000<10000
N`000`40001=0000<`020Ah000<10000NP000`40001=0000<`000`40000N00030@0007P000<10000
CP0003<000<100007`000`40001f00030@0004l0000c00030@00020000<10000M0000`40001@0000
<`000`40000Q00030@00078000<10000D@0003<00P4R00030@00074000<10000DP0003<000<10000
8P000`40001_00030@0005<0000c00030@0002<000<10000K@000`40001D0000<`000`40000T0003
0@0006/000<10000E@0002/0104400030@0002D000<10000J@000`40001F0000;@000`40000300<1
9P000`40001W00030@0005L0000]00030@0000<000<100009`020FD00P5J0000;@000`4000030003
0@0002T000<10000H@000`40001J0000;@000`40000300030@0002X000<10000G`000`40001K0000
:`030@D000<10000:`000`40001M00030@0005`0000]00030@0000<00P4]00030@0005/000<10000
G@0003<000<10000;@020EX000<10000GP0003<000<10000;`000`40001F00030@0005l0000c0003
0@00030000<10000E0000`40001P0000<`000`40000a00030@0005400P5S0000<`020C<00P5@0003
0@0006<0000c00030@0003@000<10000C0000`40001T0000<`000`40000e00030@0004X000<10000
I@0003<000<10000=P000`4000170081J00003<000<10000=`020DH000<10000J00003<00P4j0003
0@0004400P5[0000<`000`40000j00030@0003h00P5]0000<`000`40000k0081?0020Fl0000c0003
0@0003d00P4h0081L@0003<000<10000?`020C@00P5c0000<`020D800P4`0081M@0003<000<10000
@`020B`00P5g0000<`000`40001500<19`020GT0000c00030@0004P01@4M00D1N`0002/010440003
0@0004d00`4F00@1P00002d000<100000`000`40001@00P11`070H@0000]00030@0000<00`5H00L1
R`0002d000<100000`000`40003Z0000;@000`40000300030@000>X0000[00<11@000`40003Z0000
;@000`40000300030@000>X0003o02400000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.254384, 0.999999, 
  1.8987*^-8, 3.87942*^-9}}]
}, Open  ]],

Cell["(* (II) Upper Peak: Yamamoto paper *)", "Input"],

Cell[CellGroupData[{

Cell["\<\
N[
tau2[ b1
     ,I beta1[mY,e,V1]
     ,mY
     ,w
     ,k[mY,e]
     ,mY
     ,b2
     ,I beta1[mY,e,V2]
     ,mY
    ]//.{e->.240976904675electronVolt}
 ,10]\
\>", "Input"],

Cell[OutputFormData["\<\
0.9999999998953956\
\>", 
"\<\
0.9999999999\
\>"], "Output"]
}, Open  ]],

Cell["", "Input"],

Cell[CellGroupData[{

Cell["\<\
eBase=.240977;
Plot[  tau2[  b1
             ,I beta1[mY,e electronVolt,V1]
             ,mY
             ,w
             ,k[mY,e electronVolt]
             ,mY
             ,b2
             ,I beta1[mY,e electronVolt,V2]
             ,mY
           ]
      , {e,.99999eBase,1.00001eBase}];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-47618.6 197608 -1.3483e+06 1.34831e+06 [
[.30239 .0515 -24 -9 ]
[.30239 .0515 24 0 ]
[.5 .0515 -24 -9 ]
[.5 .0515 24 0 ]
[.69761 .0515 -24 -9 ]
[.69761 .0515 24 0 ]
[.89522 .0515 -24 -9 ]
[.89522 .0515 24 0 ]
[.09228 .19883 -6 -4.5 ]
[.09228 .19883 0 4.5 ]
[.09228 .33366 -6 -4.5 ]
[.09228 .33366 0 4.5 ]
[.09228 .46849 -6 -4.5 ]
[.09228 .46849 0 4.5 ]
[.09228 .60332 -6 -4.5 ]
[.09228 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.30239 .064 m
.30239 .07025 L
s
[(0.240976)] .30239 .0515 0 1 Mshowa
.5 .064 m
.5 .07025 L
s
[(0.240977)] .5 .0515 0 1 Mshowa
.69761 .064 m
.69761 .07025 L
s
[(0.240978)] .69761 .0515 0 1 Mshowa
.89522 .064 m
.89522 .07025 L
s
[(0.240979)] .89522 .0515 0 1 Mshowa
.125 Mabswid
.14431 .064 m
.14431 .06775 L
s
.18383 .064 m
.18383 .06775 L
s
.22335 .064 m
.22335 .06775 L
s
.26287 .064 m
.26287 .06775 L
s
.34191 .064 m
.34191 .06775 L
s
.38144 .064 m
.38144 .06775 L
s
.42096 .064 m
.42096 .06775 L
s
.46048 .064 m
.46048 .06775 L
s
.53952 .064 m
.53952 .06775 L
s
.57904 .064 m
.57904 .06775 L
s
.61856 .064 m
.61856 .06775 L
s
.65809 .064 m
.65809 .06775 L
s
.73713 .064 m
.73713 .06775 L
s
.77665 .064 m
.77665 .06775 L
s
.81617 .064 m
.81617 .06775 L
s
.85569 .064 m
.85569 .06775 L
s
.06526 .064 m
.06526 .06775 L
s
.02574 .064 m
.02574 .06775 L
s
.93474 .064 m
.93474 .06775 L
s
.97426 .064 m
.97426 .06775 L
s
.25 Mabswid
0 .064 m
1 .064 L
s
.10478 .19883 m
.11103 .19883 L
s
[(1)] .09228 .19883 1 0 Mshowa
.10478 .33366 m
.11103 .33366 L
s
[(1)] .09228 .33366 1 0 Mshowa
.10478 .46849 m
.11103 .46849 L
s
[(1)] .09228 .46849 1 0 Mshowa
.10478 .60332 m
.11103 .60332 L
s
[(1)] .09228 .60332 1 0 Mshowa
.125 Mabswid
.10478 .09096 m
.10853 .09096 L
s
.10478 .11793 m
.10853 .11793 L
s
.10478 .1449 m
.10853 .1449 L
s
.10478 .17186 m
.10853 .17186 L
s
.10478 .22579 m
.10853 .22579 L
s
.10478 .25276 m
.10853 .25276 L
s
.10478 .27973 m
.10853 .27973 L
s
.10478 .30669 m
.10853 .30669 L
s
.10478 .36062 m
.10853 .36062 L
s
.10478 .38759 m
.10853 .38759 L
s
.10478 .41456 m
.10853 .41456 L
s
.10478 .44152 m
.10853 .44152 L
s
.10478 .49546 m
.10853 .49546 L
s
.10478 .52242 m
.10853 .52242 L
s
.10478 .54939 m
.10853 .54939 L
s
.10478 .57635 m
.10853 .57635 L
s
.10478 .03703 m
.10853 .03703 L
s
.10478 .01007 m
.10853 .01007 L
s
.25 Mabswid
.10478 0 m
.10478 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .1327 m
.06244 .21012 L
.10458 .28662 L
.14415 .35094 L
.18221 .40591 L
.22272 .45702 L
.26171 .499 L
.30316 .53585 L
.34309 .56379 L
.3815 .58366 L
.40134 .59123 L
.41147 .59439 L
.42237 .59726 L
.43257 .59944 L
.4419 .60101 L
.44639 .60162 L
.45128 .60218 L
.45557 .60258 L
.4602 .60292 L
.46297 .60307 L
.46551 .60318 L
.46795 .60325 L
.46917 .60328 L
.46986 .60329 L
.47052 .6033 L
.47174 .60331 L
.47285 .60332 L
.47405 .60332 L
.47536 .60331 L
.47649 .6033 L
.4777 .60328 L
.47873 .60325 L
.47987 .60322 L
.48259 .60312 L
.48508 .603 L
.49069 .60262 L
.49564 .60217 L
.50085 .60156 L
.51039 .60013 L
.52059 .59813 L
.53895 .59331 L
.5603 .58573 L
.58045 .57663 L
.61892 .554 L
.65984 .52237 L
.69924 .48455 L
.73713 .44136 L
.77747 .38803 L
.81629 .32955 L
.85757 .25967 L
Mistroke
.89733 .18487 L
.93557 .10596 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`0006BEkOl0003o
0?oo0000ool0o`3ooonUChj>S_oTa?GemOoN[M?CdmWIfGAdM:VYZEnNX39DEKWEeW:OolCGociGS<d0
0;no_de=CF67fNKViW=cLjo^k[jn_ZG0`JVmj?l0VJRmj:Nlj:JljJ>kjYZhk7n[l011`_JPCObfHog5
HOOILNkXa]3HgkC^]000?`00Onc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a/JRXZ:2PX=Ro
f000_`0o000o?h:2PWmoO`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3o
O`3o_cl003l0?cl0Ocl0_cl0oclo07EeMGalO3lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo?kooOkoo_kooool0?ol0Ool0_olo
0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOooo_h9cPYVIVN[Z
jZNWYjj^[WMgMko>i[K8j;75j:o3jOooonk^k]gMgLc<c;^k^jZZZYVIVHR8R7MgMfIVIUEEEDA4A3<c
<b8R8Q4A4@000:g1jJc0jJ^ojJZojJVojJVnjJRnjJNmjJJmjJFljJBkjJBjjJ>jjJ6ijJ2gjIjfjIbd
jIVaj9J^j9:[ihfUiHJOhgjGh7F<g6UoeUeacU1PaD=@^SQ1[c4eYRd^Wbh[Vc<]VShfWeA?[j>lj`00
@PP0C`d0D0`0B`P0@P40=0008@001jNmj9bhk8N_kaU^gah000<10000o`0001h000<10000o`0001h0
0P7o0040000N00030@000?l0000N00030@000?H000<100001P0001h000<10000mP000`4000060000
7P000`40003e00030@0000L0000N00030@000?D000<100001`0001h000<10000m0000`4000080000
7P000`40000P008110000`40000200@110000`40000200810`030@@000<100000`020@`00P440003
0@000080104400030@0000800P4300<110000`40000300030@0000/00P4400030@00008010440003
0@0000800P4300<110000`40000300813@020@@000<100000P040@@000<100000P020@<00`440003
0@0000800`4:00007P020B0000@1000120000`40000500050@0000400P000`40000300050@000040
10001040004:00040@000@P000<100001@001@400001008000<100000`001@40000100D000<10000
2P001040004800030@0000D000D100000@0200030@0000<000D100000@0400040@000@/000@10001
20000`40000500050@0000400P000`40000300050@0000401@000`400@0900007P000`40000O0004
0@000@T000@100001@4200040@000@D000<100000P001@400001008000<100002000104000490004
0@0000D10P001040004500030@00008000<100000`000`40000900040@000@T000@100001@420004
0@000@D000<100000P001@400001008000<100002@001040004900040@0000D10P00104000450003
0@00008000<100000P000`400@0900007P000`40000O00040@000@X000@100010P001@4000010080
00@100000`4400040@0000<12`001040004:00040@000@8000D100000@0200040@0000<110000`40
000300030@0000T000@100012P001040004200050@0000400P00104000030@@000<100000P020@`0
00@100012P001040004200050@0000400P00104000030@@000@10000104900007P000`40000O0004
0@000@/000H10001004300040@000@8000@100011@001040004=00040@000@/000H1000100430004
0@000@8000@100011@000`40000300030@0000P000@100012`001P4000400@<000@100010P001040
004500040@000@8000<100002@001040004;00060@000@010`001040004200040@000@D000@10001
0P000`40000700007P000`40000O00040@000@P000@100010`020@<000@100010P00104000420004
0@000@8000<100002`001040004800040@000@<00P4300040@000@8000@100010P00104000420004
0@000@X000@1000120001040004300810`001040004200040@000@8000@100010P001040004;0004
0@000@P000@100010`020@<000@100010P001040004200050@000@000P4200030@0000L0000N0003
0@0002000P4:00811@000`400002008110020@<0104300<12`020@X00P4500030@0000800P440081
0`040@80104;00812P020@D000<100000P020@@00P4300@10`020@d00P4:00811@000`4000020081
10020@<010400`0100020@X0000N00030@000?0000<10000300001h000<10000l0000`40000<0000
o`4P0@40000700030@0000T000<1000020000`40000800030@0000T000<1000020000`4000080003
0@0000T000<1000020000`40000800030@0000P000<100002@000`40000800030@0000P000<10000
2@000`40000800030@0000P000<1000020000`40000900030@0000P000<1000020000`4000090003
0@0000P000<1000020000`40000200030@0000@000<100001P0001h000<10000=P000`40000e0003
0@0003D000<10000=P000`40000=00030@0000d0000N00030@000>h000<100003P0001h000<10000
kP000`40000>00007P000`40003]00030@0000l0000N00030@000>d000<100003`0001h000<10000
k0000`40000@00007P020Nd000<10000400001h000<10000j`000`40000A00007P000`40003[0003
0@000140000N00030@000>X000<100004P0001h000<10000jP000`40000B00007P000`40003Z0003
0@000180000N00030@000>T000<100004`0001h00P7Z00030@0001<0000N00030@000>P000<10000
500001h000<10000j0000`40000D00007P000`40003W00030@0001D0000700030@0001@000<10000
i`000`40000E00001`000`40000D00030@000>H000<100005P0000P000<100004`000`40003V0003
0@0001H0000800030@0001<000<10000i@000`40000G00002@000`40000B0081iP000`40000G0000
2@000`40000B00030@000>D000<100005`0000X000<100004@000`40003T00030@0001P0000:0003
0@00014000<10000i0000`40000H00002`000`40000@00030@000><000<100006@0000/000<10000
40000`40003S00030@0001T0000<00030@0000l000<10000hP000`40000J000030000`40000?0003
0@000>8000<100006P0000d000<100003P020N8000<100006`0000d000<100003P000`40003Q0003
0@0001/0000>00030@0000d000<10000h0000`40000L00003P000`40000=00030@000>0000<10000
700000l000<1000030000`40003O00030@0001d0000?00030@0000`000<10000g`000`40000M0000
40000`40000200@11@000`40003N00030@0001h0000@00030@0000@000<1000010030Mh000<10000
7P00014000<100000`000`40000400030@000=d000<100007`00014000<100000`000`4000040003
0@000=d000<100007`00018000<100000P000`40000400030@000=`000<100008000018000<10000
0`4600030@000=`000<10000800001<000D100000@0600030@000=/000<100008@0001<000<10000
20000`40003K00030@000240000D00030@0000L000<10000fP000`40000R000050000`4000070081
fP000`40000S00005@000`40000600030@000=T000<100008`0001D000<100001P000`40003H0003
0@0002@0000F00030@0000D000<10000f0000`40000T00005`000`40000400030@000=L000<10000
9@0001L000<1000010000`40003G00030@0002D0000H00030@0000<000<10000eP000`40000V0000
60000`40000300030@000=H000<100009P0001T000<100000P020MH000<100009`0001T000<10000
0P000`40003E00030@0002L0000J00050@000040eP000`40000X00006`001040007E00030@0002T0
000K00040@000MD000<10000:@0001`000<10040e0000`40000Z000070000`400@3D00030@0002X0
000M0081d`000`40000[00007@030M4000<10000;00001h000<10000d0000`40000/00007P020M00
00<10000;@0001h00P7@00030@0002d0000N00030@010<h000<10000;P0001h000<10040c@000`40
000_00007P001040007<00030@0002l0000N008100<00@00bP000`40000`00007P001@4000010<X0
00<10000<00001h000<100000P000`40003600030@000340000N00030@00008000<10000a@000`40
000b00007P000`40000300030@000<@000<10000<P0001h000<100000`000`40003300030@0003<0
000N00030@0000@000<10000`P000`40000c00005@040@D000<100001@000`40003000030@0003@0
000G00030@0000@00`4500030@000;l000<10000=@0001L000<1000010000`40000600030@000;h0
00<10000=@0001L000<1000010000`40000600030@000;d000<10000=P0001L000<1000010000`40
000700030@000;/000<10000=`0001D00`4600030@0000L000<10000^`000`40000g00005`000`40
000400030@0000P000<10000^@000`40000h00007P000`40000900030@000;L000<10000>@0001h0
00<100002@000`40002g00030@0003T0000N00812`000`40002e00030@0003X0000N00030@0000/0
00<10000/`000`40000k00007P000`40000;00030@000;8000<10000?00001h000<1000030000`40
002a00030@0003`0000N00030@0000d000<10000[`000`40000m00007P000`40000>00030@000:d0
00<10000?P0001h000<100003P000`40002]00030@0003h0000N008140000`40002[00030@0003l0
000N00030@00010000<10000Z@000`40001000007P000`40000@00030@000:T000<10000@00001h0
00<100004@000`40002W00030@000440000N00030@00018000<10000Y@000`40001200007P000`40
000B00030@000:D000<10000@P0001h000<100004`000`40002S00030@0004<0000N00030@0001@0
00<10000X@000`40001400007P020AH000<10000X0000`40001400007P000`40000F00030@0009h0
00<10000A@0001h000<100005P000`40002M00030@0004H0000N00030@0001L000<10000V`000`40
001700007P000`40000H00030@0009X000<10000A`0001h000<100006@000`40002H00030@0004P0
000N00030@0001X000<10000UP000`40001900007P000`40000K00030@0009D000<10000B@0001h0
0P4M00030@0009<000<10000BP0001h000<1000070000`40002B00030@0004/0000N00030@0001d0
00<10000T0000`40001<00007P000`40000N00030@0008h000<10000C@0001h000<100007`000`40
002<00030@0004h0000N00030@00020000<10000RP000`40001?00005@040@D000<100008@000`40
002900030@0004l0000G00030@0000@00`4R00030@0008L000<10000D00001L000<1000010000`40
000S00030@0008D000<10000D@0001L000<1000010000`40000T00030@0008<000<10000DP0001L0
00<1000010000`40000U00030@00084000<10000D`0001D00`4600030@0002D000<10000P0000`40
001D00005`000`40000400030@0002H000<10000OP000`40001E00007P000`40000W00030@0007`0
00<10000EP0001h000<10000:0000`40001j00030@0005L0000N0081:P000`40001h00030@0005P0
000N00030@0002X000<10000MP000`40001I00007P000`40000[00030@0007@000<10000FP0001h0
00<10000;0000`40001b00030@0005/0000N00030@0002d000<10000L0000`40001L00007P000`40
000^00030@0006h000<10000G@0001h000<10000;`000`40001/00030@0005h0000N00030@000300
0P5[00030@0005l0000N0081<`000`40001W00030@000600000N00030@0003<000<10000I0020F<0
000N00030@0003@000<10000HP000`40001S00007P000`40000e00030@00060000<10000I00001h0
00<10000=P000`40001M0081I`0001h000<10000=`020E`000<10000I`0001h000<10000>@000`40
001H00030@0006P0000N00030@0003X000<10000E@020F/0000N0081?0020E@000<10000J`0001h0
00<10000?@000`40001@00030@0006`0000N00030@0003h000<10000C@020Fl0000N00030@0003l0
0P5;0081L@0001h000<10000@@020DL00P5c00007P000`4000130081@`020GD0000N00030@0004D0
0P4o0081M`0001h00P580081>`020GT0000N00030@0004T00P4g0081N`0001h000<10000B`020C<0
0P5m00007P000`40001=0081;`020Gl0000N00030@0004l00P4Z00<1P@0001h000<10000D@060B40
0`6400007P000`40001G00<170020HL0000E00@11@000`40001J00@140080HT0000G00030@0000@0
0`5N0101T@0001L000<1000010000`40003o00005`000`40000400030@000?l0000G00030@0000@0
00<10000o`0001D00`4600030@000?l00000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.240975, 0.999993, 
  1.77058*^-8, 2.59496*^-9}}]
}, Open  ]],

Cell["(* (III) Lower Peak: LMS paper *)", "Input"],

Cell[CellGroupData[{

Cell["\<\
N[
tau2[ b1
     ,I beta1[m1,e,V1]
     ,m1
     ,w
     ,k[m,e]
     ,m
     ,b2
     ,I beta1[m2,e,V2]
     ,m2
    ]//.{e->.06700037275electronVolt}
 ,10]\
\>", "Input"],

Cell[OutputFormData["\<\
0.9999999999515601\
\>", "\<\
1.\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
eBase=.06700037275;
Plot[  tau2[  b1
             ,I beta1[m1,e electronVolt,V1]
             ,m1
             ,w
             ,k[m,e electronVolt]
             ,m
             ,b2
             ,I beta1[m2,e electronVolt,V2]
             ,m2
           ]
      , {e,.99999999eBase,1.00000001eBase}];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-4.76191e+07 7.10728e+08 -3.8608e+09 3.8608e+09 [
[.25125 .02066 -27 -9 ]
[.25125 .02066 27 0 ]
[.39339 .02066 -27 -9 ]
[.39339 .02066 27 0 ]
[.53554 .02066 -27 -9 ]
[.53554 .02066 27 0 ]
[.67768 .02066 -27 -9 ]
[.67768 .02066 27 0 ]
[.81983 .02066 -27 -9 ]
[.81983 .02066 27 0 ]
[.96197 .02066 -27 -9 ]
[.96197 .02066 27 0 ]
[.0966 .12968 -6 -4.5 ]
[.0966 .12968 0 4.5 ]
[.0966 .2262 -6 -4.5 ]
[.0966 .2262 0 4.5 ]
[.0966 .32272 -6 -4.5 ]
[.0966 .32272 0 4.5 ]
[.0966 .41924 -6 -4.5 ]
[.0966 .41924 0 4.5 ]
[.0966 .51576 -6 -4.5 ]
[.0966 .51576 0 4.5 ]
[.0966 .61228 -6 -4.5 ]
[.0966 .61228 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25125 .03316 m
.25125 .03941 L
s
[(0.0670004)] .25125 .02066 0 1 Mshowa
.39339 .03316 m
.39339 .03941 L
s
[(0.0670004)] .39339 .02066 0 1 Mshowa
.53554 .03316 m
.53554 .03941 L
s
[(0.0670004)] .53554 .02066 0 1 Mshowa
.67768 .03316 m
.67768 .03941 L
s
[(0.0670004)] .67768 .02066 0 1 Mshowa
.81983 .03316 m
.81983 .03941 L
s
[(0.0670004)] .81983 .02066 0 1 Mshowa
.96197 .03316 m
.96197 .03941 L
s
[(0.0670004)] .96197 .02066 0 1 Mshowa
.125 Mabswid
.13753 .03316 m
.13753 .03691 L
s
.16596 .03316 m
.16596 .03691 L
s
.19439 .03316 m
.19439 .03691 L
s
.22282 .03316 m
.22282 .03691 L
s
.27967 .03316 m
.27967 .03691 L
s
.3081 .03316 m
.3081 .03691 L
s
.33653 .03316 m
.33653 .03691 L
s
.36496 .03316 m
.36496 .03691 L
s
.42182 .03316 m
.42182 .03691 L
s
.45025 .03316 m
.45025 .03691 L
s
.47868 .03316 m
.47868 .03691 L
s
.50711 .03316 m
.50711 .03691 L
s
.56397 .03316 m
.56397 .03691 L
s
.59239 .03316 m
.59239 .03691 L
s
.62082 .03316 m
.62082 .03691 L
s
.64925 .03316 m
.64925 .03691 L
s
.70611 .03316 m
.70611 .03691 L
s
.73454 .03316 m
.73454 .03691 L
s
.76297 .03316 m
.76297 .03691 L
s
.7914 .03316 m
.7914 .03691 L
s
.84826 .03316 m
.84826 .03691 L
s
.87669 .03316 m
.87669 .03691 L
s
.90512 .03316 m
.90512 .03691 L
s
.93354 .03316 m
.93354 .03691 L
s
.08067 .03316 m
.08067 .03691 L
s
.05224 .03316 m
.05224 .03691 L
s
.02381 .03316 m
.02381 .03691 L
s
.9904 .03316 m
.9904 .03691 L
s
.25 Mabswid
0 .03316 m
1 .03316 L
s
.1091 .12968 m
.11535 .12968 L
s
[(1)] .0966 .12968 1 0 Mshowa
.1091 .2262 m
.11535 .2262 L
s
[(1)] .0966 .2262 1 0 Mshowa
.1091 .32272 m
.11535 .32272 L
s
[(1)] .0966 .32272 1 0 Mshowa
.1091 .41924 m
.11535 .41924 L
s
[(1)] .0966 .41924 1 0 Mshowa
.1091 .51576 m
.11535 .51576 L
s
[(1)] .0966 .51576 1 0 Mshowa
.1091 .61228 m
.11535 .61228 L
s
[(1)] .0966 .61228 1 0 Mshowa
.125 Mabswid
.1091 .05246 m
.11285 .05246 L
s
.1091 .07177 m
.11285 .07177 L
s
.1091 .09107 m
.11285 .09107 L
s
.1091 .11038 m
.11285 .11038 L
s
.1091 .14898 m
.11285 .14898 L
s
.1091 .16829 m
.11285 .16829 L
s
.1091 .18759 m
.11285 .18759 L
s
.1091 .2069 m
.11285 .2069 L
s
.1091 .24551 m
.11285 .24551 L
s
.1091 .26481 m
.11285 .26481 L
s
.1091 .28411 m
.11285 .28411 L
s
.1091 .30342 m
.11285 .30342 L
s
.1091 .34203 m
.11285 .34203 L
s
.1091 .36133 m
.11285 .36133 L
s
.1091 .38063 m
.11285 .38063 L
s
.1091 .39994 m
.11285 .39994 L
s
.1091 .43855 m
.11285 .43855 L
s
.1091 .45785 m
.11285 .45785 L
s
.1091 .47715 m
.11285 .47715 L
s
.1091 .49646 m
.11285 .49646 L
s
.1091 .53507 m
.11285 .53507 L
s
.1091 .55437 m
.11285 .55437 L
s
.1091 .57367 m
.11285 .57367 L
s
.1091 .59298 m
.11285 .59298 L
s
.1091 .01386 m
.11285 .01386 L
s
.25 Mabswid
.1091 0 m
.1091 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .59725 L
.10458 .58982 L
.14415 .58072 L
.18221 .56932 L
.22272 .55767 L
.26171 .54328 L
.30316 .52688 L
.34309 .50961 L
.3815 .49124 L
.42237 .46981 L
.46172 .44812 L
.49955 .42556 L
.53984 .39939 L
.57861 .3727 L
.61984 .34384 L
.65954 .31364 L
.69774 .28249 L
.73838 .24945 L
.77751 .21447 L
.81909 .17587 L
.85916 .13695 L
.89771 .09839 L
.93871 .05454 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`0006BEkOl0003o
0?oo0000ool0o`3ooonUChj>S_oTa?GemOoN[M?CdmWIfGAdM:VYZEnNX39DEKWEeW:OolCGociGS<d0
0;no_de=CF67fNKViW=cLjo^k[jn_ZG0`JVmj?l0VJRmj:Nlj:JljJ>kjYZhk7n[l011`_JPCObfHog5
HOOILNkXa]3HgkC^]000?`00Onc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a/JRXZ:2PX=Ro
f000_`0o000o?h:2PWmoO`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3o
O`3o_cl003l0?cl0Ocl0_cl0oclo07EeMGalO3lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo?kooOkoo_kooool0?ol0Ool0_olo
0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOooo_h9cPYVIVN[Z
jZNWYjj^[WMgMko>i[K8j;75j:o3jOooonk^k]gMgLc<c;^k^jZZZYVIVHR8R7MgMfIVIUEEEDA4A3<c
<b8R8Q4A4@000:g1jJc0jJ^ojJZojJVojJVnjJRnjJNmjJJmjJFljJBkjJBjjJ>jjJ6ijJ2gjIjfjIbd
jIVaj9J^j9:[ihfUiHJOhgjGh7F<g6UoeUeacU1PaD=@^SQ1[c4eYRd^Wbh[Vc<]VShfWeA?[j>lj`00
@PP0C`d0D0`0B`P0@P40=0008@001jNmj9bhk8N_kaU^gol08@000?l08@000?l08@000?l08@000?l0
8@0001d000<100002P020@@000<100000`020@@00P4400030@0000<00P44008100@00@400P400`01
000200040@010@@00P4400030@0000<00P4400@10P030@@00`44008110000`400003008110020@04
0041008100<00@000P0010400@44008110000`400003008110040@800`4400<110020@@000<10000
0`020@@00P4010010@020@030040008000@1004110020@@000<100000`020@@00P4400811@000`40
000100007@000`40000900040@000@P000@100010P001040004300030@00008000@100010P001040
004200040@000@@00P4200040@000@8000D100000@0400040@000@8000D1004100020@8000<10000
0P001040004200040@000@<000<100000P001040004200040@000@8000@1000110020@8000@10001
0P001@40000100@000@100010P001@400@4000810P000`40000200040@000@8000@100010`000`40
000200040@000@8000@100010P001040004400810P001040004200050@0000401000104000420004
0@000@8000@1000110000`40000100007@000`40000900040@000@P000@100010P00104000440005
0@0000400P001040004200040@000@8000<10040104200040@000@8000<100000P001@4000010080
00D1000100020@030041008000<1004010401@010001008000<100000P001@400001008000@10001
0P001040004200030@0100@10P001040004200030@00008000D100000@0200050@000@000P400`01
0@0200030@0100@100D00@000@0200030@00008000D100000@0200040@000@8000@100010P000`40
0@040@8000@100010P000`40000200050@0000400P001040004200040@000@8000<1004010420000
7@020@X000@1000120001040004200<11@001@400001008000@100010P001040004200030@010080
0P4200030@0000<11@001@400001008000D1000100020@030041008000<100400P001040004200<1
1@001@400001008000@100010P001040004200030@0100800P4200030@0000<11@001@4000010080
00D1000100020@030041008000<100400P001040004200<11@001@400001008000@100010P001040
004200030@0100800P4200030@0000<11@001@400001008000@100010P001040004200030@010080
00<100000@0001d000<100002@001040004800040@000@8000<100001P001040004200040@000@80
00@100010P001@40004000810P001040004800040@000@8000D1000100020@030041008000H10001
004200040@000@P000@100010P001040004200040@000@8000D1000100020@8000@1000120001040
004200050@000@000P400`010@0200060@000@010P001040004800040@000@8000@100010P001040
004200050@000@000P4200040@000@P000@100410P001040004200040@000@8000H1000100430000
7@000`40000900040@000@P000@100010P000`40000300040@000@8000@100010P00104000420004
0@000@<00`4200040@000@D000@100010P001040004200050@010@000P4200040@0000810P001040
004500040@000@8000@100010P001040004200040@000@<00`4200040@000@D000@100010P001040
004200050@010@000P4200040@0000810P001040004500040@000@8000@100010P00104000420004
0@000@<00`4200040@000@D000<100000P401@010001008000@100010P001040004300810`0001d0
00<100002P020@X00P4400<10P040@<00P44008100@00@400P4500040@010@@00`4200@10`020@@0
104200811@030@@00`4200@10`020@@00P4010010@020@D000@1004110030@801043008110040@80
0P4500<110030@801043008110020@04004100811@0010400@4400<10P040@<00P44008110020@D0
00<100000@0001d000<10000i0000`40000I00007@000`40003S00030@0001X0003o0A014@0000H0
00<100001@000`40000400030@0000D000<100001@000`40000400030@0000D000<100001@000`40
000400030@0000D000<100001@000`40000400030@0000D000<100001@000`40000500030@0000@0
00<100001@000`40000500030@0000@000<100001@000`40000500030@0000@000<100001@000`40
000500030@0000@000<100001@000`40000500030@0000@000<100001@000`40000500030@0000@0
00<100001@000`40000500030@00008000@100011P000`40000B00007@000`40003P00030@0001d0
000M00030@000=l000<100007P0001d000<10000gP000`40000O00007@020Mh000<10000800001d0
00<10000g0000`40000Q00007@000`40003K00030@000280000M00030@000=X000<100008`0001d0
00<10000f@000`40000T00007@020MT000<100009@0001d000<10000f0000`40000U00007@000`40
003G00030@0002H0000M00030@000=H000<100009`0001d000<10000e@000`40000X00007@020MD0
00<10000:@0001d000<10000d`000`40000Z00007@000`40003B00030@0002/0000M00030@000=40
00<10000;00001d000<10000d0000`40000]00007@000`40003?00030@0002h0000M0081c`000`40
000_00007@000`40003=00030@000300000M00030@000<d000<10000<00001D0104400030@000<`0
00<10000<@0001L000<100000`000`40003;00030@000380000G00030@0000<00`7:00030@0003<0
000G00030@0000<000<10000b@000`40000d00005`000`40000300030@000<P000<10000=@0001D0
0`4500030@000<L000<10000=P0001L000<100000`000`40003600030@0003L0000M0081aP000`40
000h00007@000`40003400030@0003T0000M00030@000<800P4l00007@000`40003100030@0003`0
000M00030@000<0000<10000?@0001d00P7000030@0003h0000M00030@000;h000<10000?`0001d0
00<10000_@000`40001000007@000`40002l00030@000440000M00030@000;/000<10000@P0001d0
0P6k00030@0004<0000M00030@000;T000<10000A00001d000<10000^0000`40001500007@000`40
002g00030@0004H0000M00030@000;H000<10000A`0001d000<10000]@000`40001800007@020KD0
00<10000B@0001d000<10000/`000`40001:00007@000`40002b00030@0004/0000M00030@000;40
00<10000C00001D0104400030@000:l00P5?00005`000`40000300<1[P000`40001?00005`000`40
000300030@000:d000<10000D00001L000<100000`000`40002/00030@000540000G00030@0000<0
00<10000Z`000`40001B00005@030@D000<10000Z@020ED0000G00030@0000<00P6Y00030@0005D0
000M00030@000:L000<10000EP0001d000<10000YP000`40001G00007@000`40002T0081FP0001d0
00<10000X`000`40001J00007@020J<000<10000F`0001d000<10000X@000`40001L00007@000`40
002P00030@0005d0000M00030@0009h00P5P00007@000`40002M00030@000600000M00030@0009`0
00<10000H@0001d00P6L00030@000680000M00030@0009X000<10000H`0001d000<10000V@000`40
001T00007@000`40002G0081I`0001d000<10000UP000`40001W00007@020IH000<10000J00001d0
00<10000U0000`40001Y00007@000`40002C00030@0006X0000M00030@00098000<10000J`0001D0
104400030@0009000P5^00005`000`40000300<1S`000`40001^00005`000`40000300030@0008h0
00<10000K`0001L000<100000`000`40002<0081LP0001L000<100000`000`40002;00030@000780
000E00<11@000`40002:00030@0007<0000G00030@0000<00P690081MP0001d000<10000Q`000`40
001f00007@000`4000250081N@0001d000<10000Q0000`40001i00007@000`4000220081O00001d0
0P610081OP0001d000<10000O`000`40001n00007@000`40001m0081P@0001d000<10000O0000`40
002100007@000`40001j0081Q00001d000<10000N@000`40002400007@020GT000<10000Q@0001d0
00<10000MP020HP0000M00030@0007D000<10000R00001d000<10000M0000`40002900007@000`40
001b0081S00001d00P5b00030@0008`0000M00030@0006l00P6?00007@000`40001^00030@0008l0
000M00030@0006`00P6B00005@040@@000<10000J`000`40002B00005`000`40000300<1JP000`40
002C00005`000`40000300030@0006P00P6F00005`000`40000300030@0006L000<10000UP0001L0
00<100000`000`40001U0081V@0001D00`4500030@0006<00P6K00005`000`4000030081HP020Id0
000M00030@0005l00P6O00007@000`40001M0081X@0001d000<10000G0000`40002Q00007@000`40
001J0081Y00001d00P5I0081YP0001d000<10000E`000`40002V00007@000`40001E0081Z@0001d0
00<10000D`020J/0000M00030@00058000<10000Z`0001d000<10000D0020Jh0000M0081C`020K00
000M00030@0004`00P6b00007@000`40001:0081]00001d000<10000B0020KH0000M00030@0004H0
0P6h00007@020D@00`6j00007@000`4000110081_@0001d000<10000?P030Kl0000M00030@0003/0
0`7200005@040@@000<10000>@020LD0000G00030@0000<00`4g0081a`0001L000<100000`000`40
000e0081b@0001L000<100000`000`40000c0081b`0001L000<100000`000`40000`00<1c@0001D0
0`4500030@0002h00P7@00005`000`4000030081;@020M80000M00030@0002X00P7D00007@000`40
000X0081eP0001d000<100009@030MP0000M00030@000240107K00007@000`40000N00<1g`0001d0
0P4L00<1hP0001d000<1000060030ND0000M00030@0001H00P7X00007@000`40000C00<1jP0001d0
00<1000040030Nd0000M00813@040O00000M00030@0000P0107d00007@000`40000400@1n00001d0
00<10040107l00006@060Ol00P0001<01P440081o`0200003P050@X000<10000o`0100002@050@l0
00<10000o`0100001P030A@000<10000o`0100005@040@@000<10000o`0100005`000`40000300<1
o`0100005`000`40000300030@000?l00@0001L000<100000`000`40003o0040000G00030@000?l0
1`0001D00`7o00T0000G00030@000?l01`000?l08@000001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.0670005, 1, 5.20582*^-12, 
  9.5833*^-13}}]
}, Open  ]],

Cell["(* (IV) Lower Peak: Yamamoto paper *)", "Input"],

Cell[CellGroupData[{

Cell["\<\
N[
tau2[ b1
     ,I beta1[mY,e,V1]
     ,mY
     ,w
     ,k[mY,e]
     ,mY
     ,b2
     ,I beta1[mY,e,V2]
     ,mY
    ]//.{e->.0654907635electronVolt}
 ,10]\
\>", "Input"],

Cell[OutputFormData["\<\
0.9999999999918935\
\>", "\<\
1.\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
eBase=.0654907635;
Plot[  tau2[  b1
             ,I beta1[mY,e electronVolt,V1]
             ,mY
             ,w
             ,k[mY,e electronVolt]
             ,mY
             ,b2
             ,I beta1[mY,e electronVolt,V2]
             ,mY
           ]
      , {e,.99999999eBase,1.00000001eBase}];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-8.53249e+07 1.30285e+09 -1.98898e+11 1.98898e+11 [
[.25323 .06772 -27 -9 ]
[.25323 .06772 27 0 ]
[.38351 .06772 -27 -9 ]
[.38351 .06772 27 0 ]
[.5138 .06772 -27 -9 ]
[.5138 .06772 27 0 ]
[.64408 .06772 -27 -9 ]
[.64408 .06772 27 0 ]
[.77437 .06772 -27 -9 ]
[.77437 .06772 27 0 ]
[.90465 .06772 -27 -9 ]
[.90465 .06772 27 0 ]
[.11044 .17966 -6 -4.5 ]
[.11044 .17966 0 4.5 ]
[.11044 .27911 -6 -4.5 ]
[.11044 .27911 0 4.5 ]
[.11044 .37857 -6 -4.5 ]
[.11044 .37857 0 4.5 ]
[.11044 .478 -6 -4.5 ]
[.11044 .478 0 4.5 ]
[.11044 .57745 -6 -4.5 ]
[.11044 .57745 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61804 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25323 .0802 m
.25323 .08646 L
s
[(0.0654908)] .25323 .06772 0 1 Mshowa
.38351 .0802 m
.38351 .08646 L
s
[(0.0654908)] .38351 .06772 0 1 Mshowa
.5138 .0802 m
.5138 .08646 L
s
[(0.0654908)] .5138 .06772 0 1 Mshowa
.64408 .0802 m
.64408 .08646 L
s
[(0.0654908)] .64408 .06772 0 1 Mshowa
.77437 .0802 m
.77437 .08646 L
s
[(0.0654908)] .77437 .06772 0 1 Mshowa
.90465 .0802 m
.90465 .08646 L
s
[(0.0654908)] .90465 .06772 0 1 Mshowa
.125 Mabswid
.149 .0802 m
.149 .08395 L
s
.17506 .0802 m
.17506 .08395 L
s
.20111 .0802 m
.20111 .08395 L
s
.22717 .0802 m
.22717 .08395 L
s
.27928 .0802 m
.27928 .08395 L
s
.30534 .0802 m
.30534 .08395 L
s
.3314 .0802 m
.3314 .08395 L
s
.35746 .0802 m
.35746 .08395 L
s
.40957 .0802 m
.40957 .08395 L
s
.43563 .0802 m
.43563 .08395 L
s
.46168 .0802 m
.46168 .08395 L
s
.48774 .0802 m
.48774 .08395 L
s
.53985 .0802 m
.53985 .08395 L
s
.56591 .0802 m
.56591 .08395 L
s
.59197 .0802 m
.59197 .08395 L
s
.61803 .0802 m
.61803 .08395 L
s
.67014 .0802 m
.67014 .08395 L
s
.6962 .0802 m
.6962 .08395 L
s
.72225 .0802 m
.72225 .08395 L
s
.74831 .0802 m
.74831 .08395 L
s
.80043 .0802 m
.80043 .08395 L
s
.82648 .0802 m
.82648 .08395 L
s
.85254 .0802 m
.85254 .08395 L
s
.8786 .0802 m
.8786 .08395 L
s
.09688 .0802 m
.09688 .08395 L
s
.07083 .0802 m
.07083 .08395 L
s
.04477 .0802 m
.04477 .08395 L
s
.01871 .0802 m
.01871 .08395 L
s
.93071 .0802 m
.93071 .08395 L
s
.95677 .0802 m
.95677 .08395 L
s
.98283 .0802 m
.98283 .08395 L
s
.25 Mabswid
0 .0802 m
1 .0802 L
s
.12294 .17966 m
.12919 .17966 L
s
[(1)] .11044 .17966 1 0 Mshowa
.12294 .27911 m
.12919 .27911 L
s
[(1)] .11044 .27911 1 0 Mshowa
.12294 .37857 m
.12919 .37857 L
s
[(1)] .11044 .37857 1 0 Mshowa
.12294 .478 m
.12919 .478 L
s
[(1)] .11044 .478 1 0 Mshowa
.12294 .57745 m
.12919 .57745 L
s
[(1)] .11044 .57745 1 0 Mshowa
.125 Mabswid
.12294 .1001 m
.12669 .1001 L
s
.12294 .11996 m
.12669 .11996 L
s
.12294 .13986 m
.12669 .13986 L
s
.12294 .15976 m
.12669 .15976 L
s
.12294 .19955 m
.12669 .19955 L
s
.12294 .21942 m
.12669 .21942 L
s
.12294 .23932 m
.12669 .23932 L
s
.12294 .25919 m
.12669 .25919 L
s
.12294 .29901 m
.12669 .29901 L
s
.12294 .31888 m
.12669 .31888 L
s
.12294 .33878 m
.12669 .33878 L
s
.12294 .35864 m
.12669 .35864 L
s
.12294 .39847 m
.12669 .39847 L
s
.12294 .41833 m
.12669 .41833 L
s
.12294 .43823 m
.12669 .43823 L
s
.12294 .4581 m
.12669 .4581 L
s
.12294 .49789 m
.12669 .49789 L
s
.12294 .51776 m
.12669 .51776 L
s
.12294 .53766 m
.12669 .53766 L
s
.12294 .55753 m
.12669 .55753 L
s
.12294 .0603 m
.12669 .0603 L
s
.12294 .04041 m
.12669 .04041 L
s
.12294 .02051 m
.12669 .02051 L
s
.12294 .00061 m
.12669 .00061 L
s
.12294 .59732 m
.12669 .59732 L
s
.12294 .61719 m
.12669 .61719 L
s
.25 Mabswid
.12294 0 m
.12294 .61804 L
s
0 0 m
1 0 L
1 .61804 L
0 .61804 L
closepath
clip
newpath
.5 Mabswid
.36112 0 m
.40882 .16028 L
.47725 .33023 L
.4867 .35345 L
.48804 .32907 L
.48929 .34903 L
.49059 .3479 L
.49202 .36591 L
.49439 .38498 L
.49571 .38931 L
.49692 .33191 L
.49929 .37863 L
.50148 .38498 L
.50262 .38199 L
.50388 .37668 L
.5052 .41766 L
.50643 .37323 L
.5087 .38437 L
.51077 .36157 L
.51305 .40237 L
.5142 .41281 L
.51545 .42316 L
.51779 .41104 L
.51999 .43912 L
.52197 .431 L
.52412 .4068 L
.52646 .43472 L
.52764 .41589 L
.52894 .43454 L
.53124 .45715 L
.53339 .42508 L
.53555 .44312 L
.53759 .43817 L
.53943 .4357 L
.54144 .44788 L
.54361 .44391 L
.54592 .43826 L
.5481 .45264 L
.55008 .47217 L
.55218 .48621 L
.55448 .46863 L
.55565 .45123 L
.55689 .46341 L
.55913 .48135 L
.56137 .47253 L
.56348 .4841 L
.56537 .51349 L
.56745 .50168 L
.56971 .47427 L
.57096 .49673 L
Mistroke
.57212 .46942 L
.5742 .51096 L
.57644 .48587 L
.57763 .52658 L
.57892 .50555 L
.58028 .50104 L
.58154 .50485 L
.58378 .52728 L
.58504 .51907 L
.58621 .52197 L
.58836 .51245 L
.59064 .52612 L
.59264 .52667 L
.59483 .5257 L
.59678 .51157 L
.59887 .53497 L
.60085 .53107 L
.60265 .54602 L
.60489 .52667 L
.60696 .54999 L
.60924 .53531 L
.61039 .53363 L
.61166 .5361 L
.62019 .55106 L
.62239 .51678 L
.62475 .53754 L
.62693 .53726 L
.62899 .57092 L
.6313 .53815 L
.63341 .56879 L
.63573 .56799 L
.63704 .58359 L
.63825 .54803 L
.64023 .56897 L
.64208 .5643 L
.64411 .57101 L
.64629 .57806 L
.64858 .55545 L
.65075 .5643 L
.65269 .56995 L
.65482 .57428 L
.65714 .57462 L
.65845 .5513 L
.65965 .57153 L
.66186 .57144 L
.6642 .5882 L
.66549 .58032 L
.6667 .55945 L
.66802 .56897 L
.66944 .57855 L
Mistroke
.67072 .57135 L
.67193 .56808 L
.67419 .58447 L
.67636 .57596 L
.67867 .60086 L
.68064 .60095 L
.68281 .57278 L
.68513 .5665 L
.68644 .56128 L
.68764 .59625 L
.68985 .57971 L
.69217 .57004 L
.69439 .58932 L
.69564 .56375 L
.69679 .59137 L
.69891 .57703 L
.70115 .58667 L
.70315 .56711 L
.70503 .58041 L
.70708 .57135 L
.70929 .58261 L
.71164 .56305 L
.71297 .58911 L
.7142 .55396 L
.71645 .5791 L
.71771 .58099 L
.71885 .55246 L
.72101 .60333 L
.72334 .57587 L
.72555 .56784 L
.72757 .59012 L
.72949 .58514 L
.73153 .56915 L
.73346 .57693 L
.73522 .56216 L
.73728 .59149 L
.73952 .57111 L
.74164 .57162 L
.7436 .57205 L
.74561 .58417 L
.7475 .56641 L
.74957 .57126 L
.7518 .56799 L
.75412 .56528 L
.75634 .58652 L
.75832 .55255 L
.76049 .56226 L
.76165 .55591 L
.76287 .56589 L
.76506 .5325 L
Mistroke
.76742 .56616 L
.76876 .55334 L
.77 .54971 L
.77227 .5726 L
.77433 .5575 L
.77547 .55176 L
.77671 .56827 L
.77897 .55334 L
.78114 .5408 L
.78319 .51968 L
.78532 .54611 L
.78767 .52393 L
.78969 .54123 L
.79155 .54025 L
.79358 .55414 L
.79573 .53012 L
.79808 .54776 L
.80022 .54141 L
.8014 .52039 L
.80269 .54556 L
.80502 .51773 L
.8072 .53452 L
.80952 .5181 L
.81149 .50793 L
.81367 .53204 L
.81498 .50873 L
.81622 .52029 L
.81856 .5249 L
.81986 .49866 L
.82107 .50043 L
.8224 .51367 L
.82381 .5159 L
.82504 .53418 L
.82637 .51041 L
.82763 .50598 L
.82879 .51297 L
.83098 .49609 L
.8333 .49875 L
.83549 .47949 L
.83673 .48657 L
.83788 .49265 L
.83998 .49036 L
.84221 .50388 L
.8442 .4953 L
.84606 .48126 L
.84811 .4855 L
.85032 .47119 L
.85253 .47842 L
.85379 .48233 L
.85495 .45044 L
Mistroke
.85731 .43771 L
.85863 .47552 L
.85983 .44983 L
.86198 .45627 L
.86431 .43692 L
.86651 .46933 L
.86854 .44672 L
.87044 .43002 L
.87248 .42993 L
.8744 .43491 L
.87615 .41669 L
.87821 .41608 L
.88044 .44452 L
.88256 .42563 L
.88452 .42624 L
.88652 .40063 L
.8884 .39346 L
.89047 .44257 L
.8927 .41333 L
.89491 .44028 L
.89724 .409 L
.89923 .39807 L
.90141 .39743 L
.90376 .39435 L
.90594 .3674 L
.90707 .37729 L
.90832 .36539 L
.90963 .3721 L
.91085 .37033 L
.91306 .34949 L
.91515 .36301 L
.91631 .34674 L
.91757 .35214 L
.91978 .34479 L
.92198 .35956 L
.92397 .33951 L
.92628 .3432 L
.92845 .34842 L
.93046 .34189 L
.93231 .34064 L
.93434 .34735 L
.93649 .34073 L
.93879 .30469 L
.9401 .29596 L
.9413 .29694 L
.94351 .31705 L
.94586 .31149 L
.94706 .2919 L
.94835 .3046 L
.94977 .27368 L
Mistroke
.95111 .28351 L
.95232 .26682 L
.95361 .2886 L
.95589 .25586 L
.95806 .27448 L
.96038 .25443 L
.96256 .25867 L
.96455 .26733 L
.96688 .24463 L
.96811 .20993 L
.96941 .21689 L
.97055 .22318 L
.9718 .22556 L
.97401 .23792 L
.97619 .22775 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`0006BEkOl0003o
0?oo0000ool0o`3ooonUChj>S_oTa?GemOoN[M?CdmWIfGAdM:VYZEnNX39DEKWEeW:OolCGociGS<d0
0;no_de=CF67fNKViW=cLjo^k[jn_ZG0`JVmj?l0VJRmj:Nlj:JljJ>kjYZhk7n[l011`_JPCObfHog5
HOOILNkXa]3HgkC^]000?`00Onc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a/JRXZ:2PX=Ro
f000_`0o000o?h:2PWmoO`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3o
O`3o_cl003l0?cl0Ocl0_cl0oclo07EeMGalO3lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo?kooOkoo_kooool0?ol0Ool0_olo
0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOooo_h9cPYVIVN[Z
jZNWYjj^[WMgMko>i[K8j;75j:o3jOooonk^k]gMgLc<c;^k^jZZZYVIVHR8R7MgMfIVIUEEEDA4A3<c
<b8R8Q4A4@000:g1jJc0jJ^ojJZojJVojJVnjJRnjJNmjJJmjJFljJBkjJBjjJ>jjJ6ijJ2gjIjfjIbd
jIVaj9J^j9:[ihfUiHJOhgjGh7F<g6UoeUeacU1PaD=@^SQ1[c4eYRd^Wbh[Vc<]VShfWeA?[j>lj`00
@PP0C`d0D0`0B`P0@P40=0008@001jNmj9bhk8N_kaU^gb<00P5200030@000;H0000S00030@000440
00<10000]P0002<000<10000@P000`40002e00008`000`40001200030@000;D0000S00030@000480
00<10000]@0002<00P5400030@000;@0000S00030@0004<000<10000]00002<000<10000@`000`40
002d00008`000`40001300030@000;@0000S00030@0004@000<10000/`0002<000<10000A0000`40
002c00008`020DD000<10000/`0002<000<10000A@000`40002b00008`000`40001500030@000;80
000S00030@0000T00P4400030@0000<00P4400810`030@D000@100001@4200<10`040@@00P4200@1
1@00104000040@<00P4400<110020@<00`4500040@0000@10`020@@00`4400810`030@D000@10000
1@4200<10`040@@00P4300<11@00104000040@<00P4400<110020@<00`4500040@0000<110020@@0
0P4400008`000`40000800040@000@P000@100010P001040004500030@00008000<100000`020@03
0041008000D1000100020@05004000400P001040004200030@00008000<100000P001P400@400@80
00<100000P400`010@0200040@000@D000<100000P000`40000200060@010@010P000`4000020@03
0041008000@100011@000`40000200030@0000<00P400`010@0200050@000@000P401@0100010080
00<100000`000`40000200030@00008000H10041004200030@00008100<00@400P00104000450003
0@00008000<1000010001040004200040@000@8000<100000@0002<000<100002000104000480004
0@000@8000@100011@000`400@040@@00P400`010@0200050@000@000P401@010001008000@10001
0P000`400@040@<000H10041004200030@00008100<00@400P001040004500030@0100@10`001P40
0@400@8000<100000P400`010@0200040@000@D000<100401044008100<00@400P001@4000400081
00D00@000@0200030@0000<000<10040104300060@010@010P000`4000020@030041008000@10001
1@000`400@040@D000@100010P001040004200030@000040000S00812@001040004800040@000@80
0`4300<10P001040004400<100<00@400P00104000020@8000<100000`4300<10P001040004400@1
00D00@000@03008100@00@000`4300<10P001040004400@100D00@000@03008100@00@000`4300<1
0P001040004400<100<00@400P00104000020@8000<100000`4300<10P001040004400@100D00@00
0@03008100@00@000`4300<10P001040004400<10P00104000430081100002<000<1000020001040
004800040@000@8000<100000`000`40000300030@0100<000D1004100020@8000D1000100020@05
004000401@020@@000<100400`020@05004100400P000`4000020@030041008000<100000`000`40
000300030@0100<00P401@010@01008000<100000P400`010@0200030@0000<000<100000`000`40
0@0300050@010@000P4200050@000@000P401@01000100D000<100000`000`400@03008100D00@40
0@0200030@00008100<00@400P000`40000300030@0000<000<100400`001040004200040@000@80
00@100010`0002<000<1000020001040004800040@000@8000<100000`000`40000400810`001@40
0@4000810P001@400040008100D00@000@0500811@020@<00P401@010@01008000<100000P400`01
0@0200030@0000<000<1000010020@<00P401@010@01008000<100000P400`010@0200030@0000<0
00<1000010020@<000D1004100020@8000D1000100020@05004000401@000`40000400810`020@05
004100400P000`4000020@030041008000<100000`000`40000400810`001040004200040@000@80
00@100010`0002<000<100002@020@X00P4400<10P040@@000<100000P040@800P4400@110030@80
104400030@0000800`43008110030@@00`4200@110000`40000200<10`020@@00`4400<10P040@@0
00<100000P040@800P4400@110030@80104400030@0000800`43008110030@@00`4200@110000`40
0002008110020@@00P4400008`000`40001800030@000:l0000S00030@0004P000<10000[`000?l1
804100001@000`40000500030@0000@000<100001@000`40000400030@0000D000<1000010000`40
000400030@0000D000<1000010000`40000500030@0000@000<100001@000`40000400030@0000D0
00<1000010000`40000500030@0000@000<1000010000`40000500030@0000@000<100001@000`40
000400030@0000D000<1000010000`40000500030@0000@000<100001@000`40000400030@0000D0
00<1000010000`40000400030@0000D000<1000010000`40000500030@0000@000<100001@000`40
000400030@0000@0000S00030@0004T000<10000[P0002<000<10000B@000`40002^00008`000`40
001900030@000:h0000S0081B`000`40002]00008`000`40001:00030@000:d0000S00030@0004X0
00<10000[@0002<000<10000B`000`40002/00008`000`40001;00030@000:`0000S00030@0004/0
00<10000[00002<00P5=00030@000:/0000S00030@0004`000<10000Z`0002<000<10000C0000`40
002[00008`000`40001=00030@000:X0000S00030@0004d000<10000ZP0002<000<10000C@000`40
002Z00008`020Dh000<10000ZP0002<000<10000CP000`40002Y00008`000`40001>00030@000:T0
000S00030@0004h000<10000Z@0002<000<10000C`000`40002X00008`020E0000<10000Z00002<0
00<10000C`000`40002X00008`000`40001@00030@000:L0000S00030@00050000<10000Y`0002<0
00<10000D@000`40002V00006P040@D000<10000D@000`40002V000070000`40000400<1D@000`40
002V000070000`40000400030@00058000<10000Y@0001`000<1000010000`40001B00030@000:D0
000L00030@0000@000<10000DP000`40002U00006P030@H000<10000D`000`40002T000070000`40
000400030@0005<000<10000Y00002<00P5E00030@000:<0000S00030@0005@000<10000X`0002<0
00<10000E0000`40002S00008`000`40001E00030@0009L000<10000200002<000<10000E@000`40
002G00030@0000P0000S0081E`000`40002F00030@0000P0000S00030@0005H000<10000UP020@T0
000S00030@0005H000<10000UP020@T0000S00030@0005L000<10000U@030@P0000S00030@0005L0
00<10000U@000`400@0800008`000`40001H00030@0009@000<10040200002<00P5I00030@0009@0
00<10040200002<000<10000F0000`40002D00030@0000P0000S00030@0005T000<10000T`000`40
000800008`000`40001I00030@0009<000<10000200002<000<10000F@000`40002A00030@0100X0
000S00030@0005X000<10000S`020@03004000T0000S0081F`000`40002?00<12`0002<000<10000
F`000`40002>00<12`0002<000<10000F`000`40002<00050@0100402`0002<000<10000F`000`40
002<00030@0100d0000J00@11@000`40001L00030@0008/00`4=000070000`40000400<1G0000`40
002;00813P0001`000<1000010000`40001M00030@0008X00P4>000070000`40000400030@0005d0
00<10000RP020@h0000L00030@0000@000<10000G@000`40002:00813P0001X00`4600030@0005h0
00<10000R0000`40000>000070000`40000400030@0005h000<10000QP000`400@0@00008`020F00
00<10000Q@000`400@0@00008`000`40001O00030@0008D000<10040400002<000<10000G`000`40
002500030@010100000S00030@00060000<10000Q0030A00000S00030@00060000<10000Q0030A00
000S00030@00060000<10000Q0020A40000S0081HP000`40002300030@000100000S00030@000640
00<10000P`000`40000@00008`000`40001R00030@00084000<100004@0002<000<10000HP001@40
000107l000<100004@0002<000<10000HP001`4000010040O@000`40000A00008`000`40001S0006
0@000@01O@000`40000A00008`020F@000H10001005i00030@0100814`0002<000<10000I0030@03
004007L01P4C00008`000`40001T00<100<00@00MP030@03004101@0000S00030@0006D00P400`01
001e00@15`0002<000<10000I@020@03004007D00P400`01000F00008`020FP00`5e008100<00@00
5P0002<000<10000I`030@8000<10000L0020AT0000S00030@0006L00`4200030@0006l00P4J0000
8`000`40001W00<10P000`40001^00<16P0002<000<10000I`030@03004107000`4J00006P040@D0
00<10000I`060G000P4K000070000`40000400<1I`060G000P4K000070000`40000400030@0006L0
1@400`01001^00030@0001X0000L00030@0000@000<10000I`050@03004006h000<100006P0001`0
00<1000010000`40001X00060@010@01K`000`40000J00006P030@H000<10000JP020@03004006T0
00<100000P000`40000J000070000`40000400030@0006X000@10001JP001@40000101d0000S0081
J`001040005Z00040@000Ah0000S00030@0006X000@10001JP001040004N00008`000`40001Z0004
0@000@8000<10000I@001040004N00008`000`40001Z00030@00008100<00@00IP001040004N0000
8`000`40001Z00030@00008100<00@00IP020@03004001d0000S0081J`000`4000020@03004106<0
00L100400@0101h0000S00030@0006d00`400`01001R00070@0100400@0N00008`000`40001]0007
0@0100400@1Q00070@0100400@0N00008`000`40001_00050@010040H0020@03004000817`0002<0
00<10000K`001@400@0105l00P4010010@020Al0000S00030@0006l000@100400P5N008100@00@40
0P4O00008`020G0000@100400P400`01001G00050@0100400P000`4000020Al0000S00030@000740
0`400`010@1H00050@0100400P000`4000020Al0000S00030@00078000H10001005G00050@010040
0P000`40000Q00008`000`40001b00060@000@01E`030@03004002D0000S00030@00078000<10000
0P000`400@1E00<100<00@009@0002<000<10000LP000`40000200030@0105D01@4V00008`020GP0
00<10040E@020@03004002H0000S00030@0007L000<10040E@020@03004002H0000S00030@0007L0
00<10040E@020@03004002H0000S00030@0007L000<1004010000`40001<008100@00@019`0001X0
104500030@0007L000<100400P400`010@1>008100<00@00:00001`000<1000010030GL000<10040
0P400`010@1>008100<00@00:00001`000<1000010000`40001h00050@010@000P5:00030@0000<1
:`0001`000<1000010000`40001h00050@000@000P5:00030@0000<1:`0001`000<1000010000`40
001h00050@000@000`5900030@000081;00001X00`4600030@0007/01@5800050@010040;@0001`0
00<1000010000`40001k00D1B0001@400@0102d0000S0081O0050DD000@100010P020Bd0000S0003
0@0007`000<100400P5400040@000@8000<10000;00002<000<10000O0000`400@020D@000@10041
0P000`40000/00008`000`40001l00030@010081@@020@0400400C80000S00030@0007`000<10040
0P401@01000103`00P4010010@4b00008`000`40001l00030@00008100D00@000@0l00D1<`0002<0
0P6000030@01008100<00@001@000`40000[00030@0000<000<100400P400`01000b00008`000`40
001o00030@0100@11P000`40000[00030@0000800P401P010@400C<0000S00030@0007l000@10040
0`400`01000300030@0002/00P43008100H00@41004c00008`000`40002100070@0000400@040081
;0020@8010401@01000103<0000S00030@0008D00`40100100020BL000L100000@01008010401@01
000103<0000S0081QP050@0400400BL000H100000@020@0300410081>00002<000<10000QP001040
0@020@0400400BD000H100000@020@0400410CT0000S00030@0008H000@100400P401001004U0006
0@0000401P4i00008`000`40002600030@01008000L100400@0102<000P100000@01008100<00@00
>00002<000<10000R0002P4000400@01004400030@0001`00P4200050@000040?00002<000<10000
SP020@03004000<000<100003@000`400@0:008100<00@000P4300030@0003X0000S0081S`020@07
004000400@0?00030@0100X00P400`0100020D00000S00030@0008h00P401P010001008100<00@00
0`000`40000500030@0100<000<1000010020@0300410081@00002<000<10000SP020@0600410040
0P400`01000300040@000@@000<100400`000`40000300<100@00@41@@0002<000<10000SP050@03
0041008100<00@400`001P4000400@800`401001004300D100@00@41@@0002<000<10000SP001040
0@020@0500410@000P4300050@010@000P401@010@4000<100H00@41004400030@000400000J00@1
1@000`40002@00050@000@00104010010@020@04004100X100H00@410057000070000`40000400<1
T00010400043008100H00@400@0A0@8000<10000A@0001`000<1000010000`40002@00030@0000D0
00T1000100400@002`4010010@4200030@0004D0000L00030@0000@000<10000T0000`4000050009
0@000@01004000<10P000`400@030@0400400@8000<10000A@0001`000<1000010000`40002H0004
0@00008100H00@01004200030@0100<100<00@00B`0001X00`4600030@0009`00P40100100460003
0@01008000<10000BP0001`000<1000010000`40002L008100<00@001`000`40001?00008`020Id0
0P4:00030@0004l0000S00030@0009`00P4:00030@0004l0000S00030@000?X0000S00030@000?X0
000S00030@000?X0000S0081n`000001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.065491, 1, 2.68106*^-12, 
  1.75619*^-14}}]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1152}, {0, 900}},
WindowSize->{1044, 721},
WindowMargins->{{Automatic, 6}, {6, Automatic}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 167, 3, 43, "Input"],
Cell[1901, 56, 802, 17, 173, "Print"]
}, Open  ]],
Cell[2718, 76, 66, 0, 27, "Input"],
Cell[2787, 78, 48, 0, 27, "Input"],

Cell[CellGroupData[{
Cell[2860, 82, 178, 13, 192, "Input"],
Cell[3041, 97, 74, 4, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3152, 106, 314, 13, 192, "Input"],
Cell[3469, 121, 14389, 438, 186, 4306, 309, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[17873, 562, 54, 0, 27, "Input"],

Cell[CellGroupData[{
Cell[17952, 566, 185, 13, 192, "Input"],
Cell[18140, 581, 85, 5, 25, "Output"]
}, Open  ]],
Cell[18240, 589, 17, 0, 27, "Input"],

Cell[CellGroupData[{
Cell[18282, 593, 315, 13, 192, "Input"],
Cell[18600, 608, 13000, 386, 186, 3726, 267, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[31615, 997, 50, 0, 27, "Input"],

Cell[CellGroupData[{
Cell[31690, 1001, 182, 13, 192, "Input"],
Cell[31875, 1016, 74, 4, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31986, 1025, 324, 13, 192, "Input"],
Cell[32313, 1040, 12915, 418, 186, 4282, 307, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[45243, 1461, 54, 0, 27, "Input"],

Cell[CellGroupData[{
Cell[45322, 1465, 183, 13, 192, "Input"],
Cell[45508, 1480, 74, 4, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45619, 1489, 325, 13, 192, "Input"],
Cell[45947, 1504, 19260, 700, 186, 8132, 558, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

